import Callable from '../../Container/Callable';
import ContextualBindingBuilder from '../../Container/ContextualBindingBuilder';
import { Identifier, Instantiable } from '../../Support/types';
interface IContainer {
    bound<T>(abstract: Identifier<T>): boolean;
    alias<U, V>(abstract: Identifier<U>, alias: Identifier<V>): void;
    tag<T>(abstracts: Identifier<T>[] | Identifier<T>, tags: string[]): void;
    tagged(tag: string): unknown[];
    bind<U, V>(abstract: Identifier<U>, concrete?: Identifier<V> | Function, shared?: boolean): void;
    unbind<U>(abstract: Identifier<U>): void;
    bindIf<U, V>(abstract: Identifier<U>, concrete?: Identifier<V> | Function, shared?: boolean): void;
    singleton<U, V>(abstract: Identifier<U>, concrete?: Identifier<V> | Function): void;
    extend<T>(abstract: Identifier<T>, closure: Function): void;
    instance<U, V>(abstract: Identifier<U>, instance: V): V;
    when<T>(concrete: Instantiable<T>[] | Instantiable<T>): ContextualBindingBuilder;
    factory<T>(abstract: Identifier<T>): Function;
    make<T>(abstract: Identifier<T>, parameters: any[] | object): any;
    call<T>(callback: Callable<T>, parameters?: any[] | object, defaultMethod?: string): any;
    resolved<T>(abstract: Identifier<T>): boolean;
    resolving<T>(abstract: Identifier<T> | Function, callback?: Function): void;
    afterResolving<T>(abstract: Identifier<T> | Function, callback?: Function): void;
    get<T>(id: Identifier<T>): any;
    set<U, V>(id: Identifier<U>, value: V): void;
    has<T>(id: Identifier<T>): boolean;
}
export default IContainer;
